
# This file was generated by 'versioneer.py' (0.19) from
# revision-control system data, or from the parent directory name of an
# unpacked source archive. Distribution tarballs contain a pre-generated copy
# of this file.

import json

version_json = '''
{
 "date": "2022-11-22T16:56:30+0100",
 "dirty": false,
 "error": null,
 "full-revisionid": "c4ea59ec22a76b9fd1e3f33b8d8ad3a533a831d9",
 "version": "v0.6.8"
}
'''  # END VERSION_JSON


def get_versions():
    """Get versions short version."""
    return json.loads(version_json)
